@@ -36,6 +36,7 @@ import qualified Text.TeXMath.Shared as S
 import Text.TeXMath.Readers.TeX.Macros (applyMacros, parseMacroDefinitions)
 import Text.TeXMath.Unicode.ToTeX (getSymbolType)
 import Data.Maybe (fromMaybe, fromJust)
+import Text.TeXMath.Unicode.ToUnicode (toUnicode)
 
 type TP = Parser
 
@@ -100,7 +101,8 @@ ctrlseq s = lexeme $ try $ do
   return result
 
 ignorable :: TP ()
-ignorable = skipMany (comment <|> label <|> (skipMany1 space <?> "whitespace"))
+ignorable = skipMany (comment <|> label <|> () <$ ctrlseq "nonumber" <|>
+        (skipMany1 space <?> "whitespace"))
 
 comment :: TP ()
 comment = char '%' *> skipMany (noneOf "\n") *> optional newline
@@ -155,6 +157,8 @@ expToOperatorName e = case e of
                     ESymbol _ "\x02B9" -> Just "'"
                     ESymbol _ s -> Just s
                     ENumber s -> Just s
+                    EStyled sty [EIdentifier s] ->
+                      Just (toUnicode sty s)
                     _ -> Nothing
 
 bareSubSup :: TP Exp
@@ -723,38 +727,38 @@ symbols = M.fromList
            , ("\\beta", EIdentifier "\x03B2")
            , ("\\chi", EIdentifier "\x03C7")
            , ("\\delta", EIdentifier "\x03B4")
-           , ("\\Delta", ESymbol Op "\x0394")
+           , ("\\Delta", EIdentifier "\x0394")
            , ("\\epsilon", EIdentifier "\x03F5")
            , ("\\varepsilon", EIdentifier "\x03B5")
            , ("\\eta", EIdentifier "\x03B7")
            , ("\\gamma", EIdentifier "\x03B3")
-           , ("\\Gamma", ESymbol Op "\x0393")
+           , ("\\Gamma", EIdentifier "\x0393")
            , ("\\iota", EIdentifier "\x03B9")
            , ("\\kappa", EIdentifier "\x03BA")
            , ("\\lambda", EIdentifier "\x03BB")
-           , ("\\Lambda", ESymbol Op "\x039B")
+           , ("\\Lambda", EIdentifier "\x039B")
            , ("\\mu", EIdentifier "\x03BC")
            , ("\\nu", EIdentifier "\x03BD")
            , ("\\omega", EIdentifier "\x03C9")
-           , ("\\Omega", ESymbol Op "\x03A9")
+           , ("\\Omega", EIdentifier "\x03A9")
            , ("\\phi", EIdentifier "\x03D5")
            , ("\\varphi", EIdentifier "\x03C6")
-           , ("\\Phi", ESymbol Op "\x03A6")
+           , ("\\Phi", EIdentifier "\x03A6")
            , ("\\pi", EIdentifier "\x03C0")
-           , ("\\Pi", ESymbol Op "\x03A0")
+           , ("\\Pi", EIdentifier "\x03A0")
            , ("\\psi", EIdentifier "\x03C8")
-           , ("\\Psi", ESymbol Ord "\x03A8")
+           , ("\\Psi", EIdentifier "\x03A8")
            , ("\\rho", EIdentifier "\x03C1")
            , ("\\sigma", EIdentifier "\x03C3")
-           , ("\\Sigma", ESymbol Op "\x03A3")
+           , ("\\Sigma", EIdentifier "\x03A3")
            , ("\\tau", EIdentifier "\x03C4")
            , ("\\theta", EIdentifier "\x03B8")
            , ("\\vartheta", EIdentifier "\x03D1")
-           , ("\\Theta", ESymbol Op "\x0398")
+           , ("\\Theta", EIdentifier "\x0398")
            , ("\\upsilon", EIdentifier "\x03C5")
            , ("\\Upsilon", EIdentifier "\x03A5")
            , ("\\xi", EIdentifier "\x03BE")
-           , ("\\Xi", ESymbol Op "\x039E")
+           , ("\\Xi", EIdentifier "\x039E")
            , ("\\zeta", EIdentifier "\x03B6")
            , ("\\pm", ESymbol Bin "\x00B1")
            , ("\\mp", ESymbol Bin "\x2213")
@@ -945,6 +949,7 @@ symbols = M.fromList
            , ("\\log", EMathOperator "log")
            , ("\\max", EMathOperator "max")
            , ("\\min", EMathOperator "min")
+           , ("\\mod", EMathOperator "mod")
            , ("\\Pr", EMathOperator "Pr")
            , ("\\sec", EMathOperator "sec")
            , ("\\sin", EMathOperator "sin")
